# constellaXion CLI

The fastest way to Train, Deploy and Serve Open Source Language Models to your Cloud environment

## Installation

Install the package:

```sh
pip install constellaxion
```


## Usage
1. Init your model:

    ```sh
    constellaXion init
    ```

2. View Training and Serving configurations:

    ```sh
    constallaXion job view
    ```

3. Train, Deploy and Serve model:

    ```sh
    constallaXion job run
    ```
